package cn.iocoder.yudao.module.delivery.controller.admin;


import cn.iocoder.yudao.framework.common.pojo.CommonResult;
import cn.iocoder.yudao.framework.common.pojo.PageResult;
import cn.iocoder.yudao.framework.dict.core.dto.DictDataRespDTO;
import cn.iocoder.yudao.framework.operatelog.core.annotations.OperateLog;
import cn.iocoder.yudao.module.delivery.entity.CustomerAnalysisReq;

import cn.iocoder.yudao.module.delivery.entity.SalesAnalysisReq;
import cn.iocoder.yudao.module.delivery.entity.SalesAnalysisResp;
import cn.iocoder.yudao.module.delivery.service.SalesAnalysisService;
import cn.iocoder.yudao.module.system.api.dict.DictDataApi;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletResponse;
import javax.validation.Valid;
import java.io.IOException;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import static cn.iocoder.yudao.framework.common.pojo.CommonResult.success;
import static cn.iocoder.yudao.framework.operatelog.core.enums.OperateTypeEnum.EXPORT;

/**
 * (SalesAnalysis)销售分析报表
 *
 * @author lanbm add
 * @since 2024-03-31
 */
@RestController
@RequestMapping("/Report/SalesAnalysis")
public class SalesAnalysisControl {

    @Autowired
    private SalesAnalysisService salesAnalysisService;

    /*
    数据字典项
    */
    @Autowired
    private DictDataApi dictDataApi;

    /*
    客户分析列表 lanbm 2024-04-02 add
    */
    @GetMapping("/getListPage")
    public CommonResult<PageResult<SalesAnalysisResp>> getListPage(@Valid SalesAnalysisReq query) {

        /*
        SalesAnalysisReq query = JSON.parseObject(JSON.toJSONString(map),
                SalesAnalysisReq.class);

         */

        //订单状态
        List<DictDataRespDTO> dic_order_status =
                dictDataApi.getDictDatas("order_status");
        Map<String, String> map_order_status = new HashMap<>();
        for (DictDataRespDTO d : dic_order_status
        ) {
            map_order_status.put(d.getValue(), d.getLabel());
        }

        PageResult<SalesAnalysisResp> pageResult =
                salesAnalysisService.getListPage(query);

        int nPm = query.getStart() + 1;
        for (SalesAnalysisResp r : pageResult.getList()
        ) {
            r.setPx(nPm);
            nPm++;

            //订单状态
            r.setStatusName(map_order_status.get(r.getStatus()));

            if(r.getTransportId()=="1")
                r.setTransportIdName("海运拼柜");
            else if(r.getTransportId()=="3")
                r.setTransportIdName("专线空运");


        }

        return success(pageResult);
    }

    @GetMapping("/exportExcel")
    @ApiOperation("导出销售分析数据")
    @OperateLog(type = EXPORT)
    public void export(HttpServletResponse response, @Valid CustomerAnalysisReq Req) throws IOException {
        // List<DictDataDO> list = dictDataService.getDictDatas(reqVO);
        //List<DictDataExcelVO> data = DictDataConvert.INSTANCE.convertList02(list);
        // 输出
        //ExcelUtils.write(response, "客户分析数据.xls", "客户分析数据列表", DictDataExcelVO.class, data);
    }
}
